<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :span="6">
            <a-form-item label="设备所属分类">
              <j-search-select-tag
                dict="mom_eam_equipment_category,name,id"
                v-model="queryParam.equipmentCategoryId"
              />
            </a-form-item>
          </a-col>
          <a-col
          :span="6"
          >
            <a-form-item label="统一编码">
              <j-input
                placeholder="请输入设备统一编码查询"
                v-model="queryParam.num"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
          :span="6"
          >
            <a-form-item label="设备名称">
              <j-input
                placeholder="请输入设备名称查询"
                v-model="queryParam.name"
              ></j-input>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        @click="searchReset"
        icon="reload"
      >重置</a-button>
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('设备台账')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl" @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
        :customRow="clickThenSelect"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

         <!--工艺参数个性展示-->
      <span
        slot="processParameters"
        slot-scope="text,record"
      >
        <a-badge
          v-if="record.processParameters==1"
          status="success"
        />
        <span
          v-if="record.processParameters==1"
          class="success"
        >是</span>
        <a-badge
          v-if="record.processParameters==0"
          status="error"
        />
        <span
          v-if="record.processParameters==0"
          class="error"
        >否</span>
      </span>
      <span
        slot="processParameters"
        slot-scope="text,record"
      >
        <a-badge
          v-if="record.processParameters==1"
          status="success"
        />
        <span
          v-if="record.processParameters==1"
          class="success"
        >是</span>
        <a-badge
          v-if="record.processParameters==0"
          status="error"
        />
        <span
          v-if="record.processParameters==0"
          class="error"
        >否</span>
      </span>
      <span
        slot="precisionParameters"
        slot-scope="text,record"
      >
        <a-badge
          v-if="record.precisionParameters==1"
          status="success"
        />
        <span
          v-if="record.precisionParameters==1"
          class="success"
        >是</span>
        <a-badge
          v-if="record.precisionParameters==0"
          status="error"
        />
        <span
          v-if="record.precisionParameters==0"
          class="error"
        >否</span>
      </span>
      <span
        slot="verification"
        slot-scope="text,record"
      >
        <a-badge
          v-if="record.verification==1"
          status="success"
        />
        <span
          v-if="record.verification==1"
          class="success"
        >是</span>
        <a-badge
          v-if="record.verification==0"
          status="error"
        />
        <span
          v-if="record.verification==0"
          class="error"
        >否</span>
      </span>

      <span
        slot="action"
        slot-scope="text, record"
      >
        <!-- class="table-operation" -->
        <!-- <a
          href="javascript:;"
          @click="equipmentStructuresShow(record)"
        >设备结构</a>
        <a-divider type="vertical" /> -->
        <a
          href="javascript:;"
          @click='handleDetail(record)'
        >详情</a>
        <a-divider type="vertical" />
        <a-dropdown>
          <a class="ant-dropdown-link">
            更多
            <a-icon type="down" />
          </a>
          <a-menu slot="overlay">
            <a-menu-item>
              <a @click="equipmentResumeShow(record)">设备履历</a>
            </a-menu-item>
            <a-menu-item>
              <a @click="handleEdit(record)">编辑</a>
            </a-menu-item>
            <a-menu-item>
              <a-popconfirm
                title="确定删除吗?"
                @confirm="() => handleDelete(record.id)"
              >
                <a>删除</a>
              </a-popconfirm>
            </a-menu-item>
          </a-menu>
        </a-dropdown>
      </span>
      </a-table>
    </div>
    <equipment-resume-drawer
      ref="EquipmentResumeDrawer"
      @ok="modalFormOk"
    ></equipment-resume-drawer>

    <a-tabs defaultActiveKey="1">
      <a-tab-pane tab="工艺参数" key="1" >
        <EquipmentProcessParametersList :mainId="equipmentProcessParametersMainId" />
      </a-tab-pane>
      <a-tab-pane tab="设备精度" key="2" forceRender>
        <EquipmentPrecisionParametersList :mainId="equipmentPrecisionParametersMainId" />
      </a-tab-pane>
      <a-tab-pane tab="设备文档" key="3" forceRender>
        <EquipmentDocumentList :mainId="equipmentDocumentMainId" />
      </a-tab-pane>
    </a-tabs>
    <equipment-modal ref="modalForm" @ok="modalFormOk"></equipment-modal>
  </a-card>
</template>

<script>

  import { JeecgListMixin } from '@/mixins/JeecgListMixin'
  import { mixinDevice } from '@/utils/mixin'
  import EquipmentModal from './modules/equipmentNew/EquipmentModal'
  import { getAction } from '@/api/manage'
  import EquipmentProcessParametersList from './modules/equipmentNew/EquipmentProcessParametersList'
  import EquipmentDocumentList from './modules/equipmentNew/EquipmentDocumentList'
  import EquipmentPrecisionParametersList from './modules/equipmentNew/EquipmentPrecisionParametersList'
  import '@/assets/less/TableExpand.less'
  import EquipmentResumeDrawer from './modules/equipmentNew/EquipmentResume/EquipmentResumeDrawer'
import JSearchSelectTag from '../../components/dict/JSearchSelectTag.vue'

 
  export default {
    name: "EquipmentList",
    mixins:[JeecgListMixin,mixinDevice],
    components: {
      EquipmentProcessParametersList,
      EquipmentDocumentList,
      EquipmentPrecisionParametersList,
      EquipmentModal,
      EquipmentResumeDrawer,
        JSearchSelectTag
    },
    data () {
      return {
        description: '设备台账管理页面',
        // 表头
        columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '设备类型',
          align: "center",
          dataIndex: 'equipmentCategoryId_dictText',
        },
        {
          title: '统一编码',
          align: "center",
          dataIndex: 'num',
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'name',
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'model',
        },
        {
          title: '规格',
          align: "center",
          dataIndex: 'specification',
        },
        {
          title: '总功率',
          align: "center",
          dataIndex: 'gpo',
        },
        {
          title: '使用部门',
          align: "center",
          dataIndex: 'useId_dictText',
        },
        {
          title: '维护部门',
          align: "center",
          dataIndex: 'manageId_dictText',
        },
        {
          title: '维修班组',
          align: "center",
          dataIndex: 'teamId_dictText',
        },
        {
          title: 'ABC标识',
          align: "center",
          dataIndex: 'equipmentImportanceId',
        },
        {
          title: '关键设备标识',
          align: "center",
          dataIndex: 'specificEquipment_dictText',
        },
        // {
        //   title: '工区',
        //   align: "center",
        //   dataIndex: 'equipmentUda1',
        // },
        // {
        //   title: '安全配置',
        //   align: "center",
        //   dataIndex: 'securityConfiguration',
        // },
        // {
        //   title: '冷却系统',
        //   align: "center",
        //   dataIndex: 'coolingSystem',
        // },
        // {
        //   title: '灭火器',
        //   align: "center",
        //   dataIndex: 'fireExtinguisher',
        // },
        
        // {
        //   title: '灭火器有效期',
        //   align: "center",
        //   dataIndex: 'fireExtinguisherValidityPeriod',
        // },
        // {
        //   title: '操作系统',
        //   align: "center",
        //   dataIndex: 'operatingSystem',
        // },
        // {
        //   title: '系统',
        //   align: "center",
        //   dataIndex: 'system',
        // },
        // {
        //   title: '设备端口',
        //   align: "center",
        //   dataIndex: 'port',
        // },
        // {
        //   title: '坐标数量',
        //   align: "center",
        //   dataIndex: 'coordinateNum',
        // },
        // {
        //   title: '设备状态',
        //   align: "center",
        //   dataIndex: 'equipmentStatus_dictText',
        // },
        // {
        //   title: '重量',
        //   align: "center",
        //   dataIndex: 'equipmentUda3',
        // },
        // {
        //   title: '重量计量单位',
        //   align: "center",
        //   dataIndex: 'equipmentUda4_dictText',
        // },
        // {
        //   title: '功能位置',
        //   align: "center",
        //   dataIndex: 'equipmentUda5',
        // },
        // {
        //   title: '安装位置',
        //   align: "center",
        //   dataIndex: 'equipmentUda2',
        // },
        // {
        //   title: '出厂日期',
        //   align: "center",
        //   dataIndex: 'leaveFactoryDate',
        // },
        // {
        //   title: '立项卡号',
        //   align: "center",
        //   dataIndex: 'projectApprovalNo',
        // },
        // {
        //   title: '资金来源',
        //   align: "center",
        //   dataIndex: 'fundSource',
        // },
        // {
        //   title: '验收日期',
        //   align: "center",
        //   dataIndex: 'acceptanceCheckDate',
        // },
        // {
        //   title: '出厂编号',
        //   align: "center",
        //   dataIndex: 'factoryNo',
        // },
        // {
        //   title: '资产制造商',
        //   align: "center",
        //   dataIndex: 'constructorId_dictText',
        // },
        // {
        //   title: '资产的来源国家',
        //   align: "center",
        //   dataIndex: 'sourceCountry',
        // }, 
        {
          title: '工艺参数管理',
          align: "center",
          dataIndex: 'processParameters',
          scopedSlots: { customRender: 'processParameters' },
        },
        {
          title: '工艺参数模板',
          align: "center",
          dataIndex: 'processParametersTemplateId_dictText',
        },
        {
          title: '设备精度管理',
          align: "center",
          dataIndex: 'precisionParameters',
          scopedSlots: { customRender: 'precisionParameters' },
        },
        {
          title: '精度参数模板',
          align: "center",
          dataIndex: 'precisionParametersTemplateId_dictText',
        },
        // {
        //   title: '备注',
        //   align: "center",
        //   dataIndex: 'remark',
        // },
        {
          title: '操作',
          align: "center",
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action',
          },
          width: 200,
          fixed: 'right',
        },
        ],
        url: {
          list: "/eam/equipment/getEquipmentList",
          delete: "/eam/equipment/delete",
          deleteBatch: "/eam/equipment/deleteBatch",
          active: "/eam/equipment/active",
          exportXlsUrl: '/eam/equipment/exportXls',
          importExcelUrl: "/eam/equipment/importExcel",
        },
        dictOptions:{
        },
        /* 分页参数 */
        ipagination:{
          current: 1,
          pageSize: 5,
          pageSizeOptions: ['5', '10', '50'],
          showTotal: (total, range) => {
            return range[0] + "-" + range[1] + " 共" + total + "条"
          },
          showQuickJumper: true,
          showSizeChanger: true,
          total: 0
        },
        selectedMainId:'',
        superFieldList:[],
        equipmentProcessParametersMainId: '',
        equipmentDocumentMainId: '',
        equipmentPrecisionParametersMainId: '',
      }
    },
    created() {
      this.getSuperFieldList();
    },
    computed: {
      importExcelUrl: function(){
        return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
      }
    },
    methods: {
      initDictConfig(){
      },
      equipmentResumeShow(record) {
      this.$refs.EquipmentResumeDrawer.visible = true
      this.$refs.EquipmentResumeDrawer.title = '设备履历'
      this.$refs.EquipmentResumeDrawer.handleShow(record)
       },
      clickThenSelect(record) {
        return {
          on: {
            click: () => {
              this.onSelectChange(record.id.split(","), [record]);
            }
          }
        }
      },
      onClearSelected() {
        this.selectedRowKeys = [];
        this.selectionRows = [];
        this.selectedMainId=''
      },
      onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedMainId=selectedRowKeys[0]
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;
        this.equipmentProcessParametersMainId = selectionRows[0]['id']
        this.equipmentDocumentMainId = selectionRows[0]['id']
        this.equipmentPrecisionParametersMainId = selectionRows[0]['id']
      },
      loadData(arg) {
        if(!this.url.list){
          this.$message.error("请设置url.list属性!")
          return
        }
        //加载数据 若传入参数1则加载第一页的内容
        if (arg === 1) {
          this.ipagination.current = 1;
        }
        this.onClearSelected()
        var params = this.getQueryParams();//查询条件
        this.loading = true;
        getAction(this.url.list, params).then((res) => {
          if (res.success) {
            this.dataSource = res.result.records;
            this.ipagination.total = res.result.total;
          }
          if(res.code===510){
            this.$message.warning(res.message)
          }
          this.loading = false;
        })
      },
      getSuperFieldList(){
        let fieldList=[];
        fieldList.push({type:'string',value:'num',text:'统一编码',dictCode:''})
        fieldList.push({type:'string',value:'name',text:'设备名称',dictCode:''})
        fieldList.push({type:'string',value:'model',text:'型号',dictCode:''})
        fieldList.push({type:'string',value:'specification',text:'规格',dictCode:''})
        fieldList.push({type:'string',value:'equipmentStatus',text:'设备状态',dictCode:''})
        fieldList.push({type:'string',value:'technologyStatus',text:'technologyStatus',dictCode:''})
        fieldList.push({type:'string',value:'assetNumber',text:'assetNumber',dictCode:''})
        fieldList.push({type:'string',value:'equipmentCategoryId',text:'equipmentCategoryId',dictCode:''})
        fieldList.push({type:'string',value:'specificEquipment',text:'specificEquipment',dictCode:''})
        fieldList.push({type:'string',value:'equipmentPhoto',text:'equipmentPhoto',dictCode:''})
        fieldList.push({type:'string',value:'constructorId',text:'资产制造商',dictCode:''})
        fieldList.push({type:'string',value:'supplierId',text:'supplierId',dictCode:''})
        fieldList.push({type:'string',value:'factoryNumber',text:'factoryNumber',dictCode:''})
        fieldList.push({type:'string',value:'leaveFactoryDate',text:'出厂日期',dictCode:''})
        fieldList.push({type:'string',value:'acceptanceCheckDate',text:'验收日期',dictCode:''})
        fieldList.push({type:'string',value:'affiliationId',text:'affiliationId',dictCode:''})
        fieldList.push({type:'string',value:'manageId',text:'维护部门ID',dictCode:''})
        fieldList.push({type:'string',value:'manager',text:'manager',dictCode:''})
        fieldList.push({type:'string',value:'useId',text:'使用部门ID',dictCode:''})
        fieldList.push({type:'string',value:'functionary',text:'functionary',dictCode:''})
        fieldList.push({type:'string',value:'location',text:'location',dictCode:''})
        fieldList.push({type:'string',value:'equipmentImportanceId',text:'ABC标识ID',dictCode:''})
        fieldList.push({type:'string',value:'processParameters',text:'processParameters',dictCode:''})
        fieldList.push({type:'string',value:'processParametersTemplateId',text:'processParametersTemplateId',dictCode:''})
        fieldList.push({type:'string',value:'precisionParameters',text:'precisionParameters',dictCode:''})
        fieldList.push({type:'string',value:'precisionParametersTemplateId',text:'precisionParametersTemplateId',dictCode:''})
        fieldList.push({type:'string',value:'verification',text:'verification',dictCode:''})
        fieldList.push({type:'string',value:'verificationPeriod',text:'verificationPeriod',dictCode:''})
        fieldList.push({type:'string',value:'lastVerificationDate',text:'lastVerificationDate',dictCode:''})
        fieldList.push({type:'string',value:'nextVerificationDate',text:'nextVerificationDate',dictCode:''})
        fieldList.push({type:'string',value:'status',text:'status',dictCode:''})
        fieldList.push({type:'string',value:'remark',text:'remark',dictCode:''})
        fieldList.push({type:'string',value:'equipmentUda1',text:'工区',dictCode:''})
        fieldList.push({type:'string',value:'equipmentUda2',text:'安装位置',dictCode:''})
        fieldList.push({type:'string',value:'equipmentUda3',text:'重量',dictCode:''})
        fieldList.push({type:'string',value:'equipmentUda4',text:'重量计量单位ID',dictCode:''})
        fieldList.push({type:'string',value:'equipmentUda5',text:'功能位置',dictCode:''})
        fieldList.push({type:'string',value:'tenantId',text:'tenantId',dictCode:''})
        fieldList.push({type:'int',value:'delFlag',text:'delFlag',dictCode:''})
        fieldList.push({type:'string',value:'teamId',text:'维修班组ID',dictCode:''})
        fieldList.push({type:'string',value:'sourceId',text:'sourceId',dictCode:''})
        fieldList.push({type:'string',value:'fundSource',text:'资金来源',dictCode:''})
        fieldList.push({type:'string',value:'factoryNo',text:'出厂编号',dictCode:''})
        fieldList.push({type:'string',value:'mfr',text:'制造商',dictCode:''})
        fieldList.push({type:'string',value:'sourceCountry',text:'资产来源国家',dictCode:''})
        fieldList.push({type:'string',value:'gpo',text:'总功率',dictCode:''})
        fieldList.push({type:'string',value:'keyEquipmentIdentification',text:'关键设备标识',dictCode:''})
        fieldList.push({type:'string',value:'securityConfiguration',text:'安全配置',dictCode:''})
        fieldList.push({type:'string',value:'coolingSystem',text:'冷却系统',dictCode:''})
        fieldList.push({type:'string',value:'fireExtinguisher',text:'灭火器',dictCode:''})
        fieldList.push({type:'string',value:'fireExtinguisherValidityPeriod',text:'灭火器有效期',dictCode:''})
        fieldList.push({type:'string',value:'operatingSystem',text:'操作系统',dictCode:''})
        fieldList.push({type:'string',value:'system',text:'系统',dictCode:''})
        fieldList.push({type:'string',value:'port',text:'端口',dictCode:''})
        fieldList.push({type:'BigDecimal',value:'coordinateNum',text:'坐标数量',dictCode:''})
        fieldList.push({type:'string',value:'projectApprovalNo',text:'立项卡号',dictCode:''})
        this.superFieldList = fieldList
      }
    }
  }
</script>
<style scoped>
  @import '~@assets/less/common.less'
</style>